# -*- coding: utf-8 -*-
import werkzeug.urls

from uuid import uuid4

from odoo import api, models, fields

class ChatRoom(models.Model):
    _inherit = 'chat.room'

    def _default_room_uuid(self):
        return str(uuid4())

    room_uuid = fields.Char(default=_default_room_uuid,
        help="UUID of the channel on discuss server, empty to fallback on jitsi")
    discuss_url = fields.Char(compute='_compute_discuss_url')

    def _compute_discuss_url(self):
        ICP = self.env['ir.config_parameter'].sudo()
        domain_name = ICP.get_param('website_discuss.discuss_server_domain')
        for rec in self:
            if rec.room_uuid and domain_name:
                rec.discuss_url = werkzeug.urls.url_quote("https://{domain_name}/chat/{uuid}/{name}".format(
                    domain_name=domain_name,
                    uuid=rec.room_uuid,
                    name=rec.name
                ))
            else:
                rec.discuss_url = False
